@@ -92,7 +92,7 @@ class MILC(BaseModel):
         }
 
         if params is not None:
-            self.set_paramerters(**params)
+            self.set_parameters(**params)
 
     def __repr__(self):
         text = "\n______________MILC structure______________\n"
@@ -182,7 +182,7 @@ class MILC(BaseModel):
         if kwargs:
             self.area = kwargs.get("area", self.area)
             self.lat = kwargs.get("lat", self.lat)
-            self.set_paramerters(**kwargs)
+            self.set_parameters(**kwargs)
 
         # Get Forcings
         prec = forcings["prec"].values
