@@ -207,7 +207,7 @@ def plot_correlation(yobs, ysim, reg=False, log=False, scores=True, ax=None, **k
     if title:
         ax.set_title(title, fontsize=kwargs.get("fontsize", 12))
     if fig is not None:
-        plt.tight_layout()
+        fig.tight_layout()
     return ax
 
 
@@ -228,6 +228,7 @@ def daily_median(serie, ci=None, color="k", ylabel=None, ax=None, **kwargs):
     days = serie.index.dayofyear
     sm = serie.groupby(days).median()
 
+    fig = None
     if ax is None:
         fig, ax = plt.subplots(figsize=kwargs.get("figsize", (8, 4)))
 
@@ -246,7 +247,8 @@ def daily_median(serie, ci=None, color="k", ylabel=None, ax=None, **kwargs):
     ax.set_ylabel(ylabel, fontsize=kwargs.get("fontsize", 12))
     ax.set_xlabel("Day of year", fontsize=kwargs.get("fontsize", 12))
     ax.grid(kwargs.get("grid", True))
-    plt.tight_layout()
+    if fig is not None:
+        fig.tight_layout()
     plt.show()
     return ax
 
@@ -334,6 +336,7 @@ def flow_duration_curves(streamflow, attrs=None, labels=None, ylabel="Streamflow
     # Compute flow duration curves
     data = [ts.flow_duration_curve(x) for x in data]
 
+    fig = None
     if ax is None:
         fig, ax = plt.subplots(figsize=kwargs.get("figsize", (5, 5)))
 
@@ -382,7 +385,8 @@ def flow_duration_curves(streamflow, attrs=None, labels=None, ylabel="Streamflow
     ax.grid(True, which="both")
     if labels:
         ax.legend(loc=0)
-    plt.tight_layout()
+    if fig is not None:
+        fig.tight_layout()
     plt.show()
     return ax
 
